.. _mission-statement:
.. redirect-from:: /users/project/mission

Mission Statement
=================

The Matplotlib developer community develops, maintains, and supports Matplotlib
and its extensions to provide data visualization tools for the Scientific
Python Ecosystem.

Adapting the requirements :ref:`laid out by John Hunter <project_history>`
Matplotlib should:

* Support users of the Scientific Python ecosystem;
* Facilitate interactive data exploration;
* Produce high-quality raster and vector format outputs suitable for publication;
* Provide a simple graphical user interface and support embedding in applications;
* Be understandable and extensible by people familiar with data processing in Python;
* Make common plots easy, and novel or complex visualizations possible.

We believe that a diverse developer community creates the best software, and we
welcome anyone who shares our mission, and our values described in the `code of
conduct
<https://github.com/matplotlib/matplotlib/blob/main/CODE_OF_CONDUCT.md>`__.
